changeset 20403:599b5a4aebab

The last of the merge fix-ups.
author Richard Laager <rlaager@wiktel.com>
date Sun, 15 Apr 2007 05:28:07 +0000
parents 00e7d8ded567
children 455c5700c866
files libpurple/protocols/msn/contact.c libpurple/protocols/msn/dialog.c libpurple/protocols/msn/msnutils.c libpurple/protocols/msn/userlist.c
diffstat 4 files changed, 14 insertions(+), 15 deletions(-) [+]
line wrap: on
line diff
--- a/libpurple/protocols/msn/contact.c	Sun Apr 15 05:01:55 2007 +0000
+++ b/libpurple/protocols/msn/contact.c	Sun Apr 15 05:28:07 2007 +0000
@@ -395,6 +395,7 @@
 			friendly = xmlnode_get_data(xmlnode_get_child(contactInfo, "displayName"));
 			purple_connection_set_display_name(session->account->gc, purple_url_decode(friendly));
 			g_free(friendly);
+			continue; /* Not adding own account as buddy to buddylist */
 		}
 
 		passportName = xmlnode_get_child(contactInfo,"passportName");
@@ -876,4 +877,3 @@
 					msn_contact_login_connect_cb,
 					msn_contact_login_error_cb);
 }
-
--- a/libpurple/protocols/msn/dialog.c	Sun Apr 15 05:01:55 2007 +0000
+++ b/libpurple/protocols/msn/dialog.c	Sun Apr 15 05:28:07 2007 +0000
@@ -117,7 +117,6 @@
 		buddy = purple_find_buddy_in_group(account, passport, group);
 	else
 		buddy = purple_find_buddy(account, passport);
-	}
 
 	if (buddy != NULL)
 		purple_blist_remove_buddy(buddy);
--- a/libpurple/protocols/msn/userlist.c	Sun Apr 15 05:01:55 2007 +0000
+++ b/libpurple/protocols/msn/userlist.c	Sun Apr 15 05:28:07 2007 +0000
@@ -287,7 +287,7 @@
 	if (list_id == MSN_LIST_FL)
 	{
 		/* TODO: When is the user totally removed? */
-		if (group_id >= 0)
+		if (group_id != NULL)
 		{
 			msn_user_remove_group_id(user, group_id);
 			return;
--- a/libpurple/protocols/msn/msnutils.c	Sun Apr 15 05:01:55 2007 +0000
+++ b/libpurple/protocols/msn/msnutils.c	Sun Apr 15 05:28:07 2007 +0000
@@ -168,7 +168,7 @@
 {
 	char *base64;
 	
-	base64 = gaim_base64_encode((guchar *)str, strlen(str));
+	base64 = purple_base64_encode((guchar *)str, strlen(str));
 	return g_strdup_printf("=?utf-8?B?%s?=", base64);
 }
 
@@ -481,7 +481,7 @@
 	struct tm ctime;
 	time_t ts;
 
-	gaim_debug_info("MaYuan","convert string is{%s}\n",timestr);
+	purple_debug_info("MaYuan","convert string is{%s}\n",timestr);
 	tzset();
 	/*copy string first*/
 	memset(temp, 0, sizeof(temp));
@@ -528,8 +528,8 @@
 void 
 msn_handle_chl(char *input, char *output)
 {
-		GaimCipher *cipher;
-		GaimCipherContext *context;
+		PurpleCipher *cipher;
+		PurpleCipherContext *context;
 		char *productKey = MSNP13_WLM_PRODUCT_KEY,
 			 *productID  = MSNP13_WLM_PRODUCT_ID,
 			 *hexChars   = "0123456789abcdef",
@@ -544,16 +544,16 @@
 		/* Determine our endianess */
 		bigEndian = isBigEndian();
 
-		/* Create the MD5 hash by using Gaim MD5 algorithm*/
-		cipher = gaim_ciphers_find_cipher("md5");
-		context = gaim_cipher_context_new(cipher, NULL);
+		/* Create the MD5 hash by using Purple MD5 algorithm*/
+		cipher = purple_ciphers_find_cipher("md5");
+		context = purple_cipher_context_new(cipher, NULL);
 
-		gaim_cipher_context_append(context, (const guchar *)input,
+		purple_cipher_context_append(context, (const guchar *)input,
 						strlen(input));
-		gaim_cipher_context_append(context, (const guchar *)productKey,
+		purple_cipher_context_append(context, (const guchar *)productKey,
 						strlen(productKey));
-		gaim_cipher_context_digest(context, sizeof(md5Hash), md5Hash, NULL);
-		gaim_cipher_context_destroy(context);
+		purple_cipher_context_digest(context, sizeof(md5Hash), md5Hash, NULL);
+		purple_cipher_context_destroy(context);
 
 		/* Split it into four integers */
 		md5Parts = (unsigned int *)md5Hash;
@@ -614,7 +614,7 @@
 
 		output[32]='\0';
 
-//		gaim_debug_info("MaYuan","chl output{%s}\n",output);
+//		purple_debug_info("MaYuan","chl output{%s}\n",output);
 }
 
 #if (!defined(_XOPEN_SOURCE))||defined(_WIN32)